@@ -15,6 +15,11 @@ router.register(
     views.EnterpriseLearnerEnrollmentViewSet,
     'enterprise-learner-enrollment',
 )
+router.register(
+    r'enterprise/(?P<enterprise_id>.+)/offers',
+    views.EnterpriseOfferViewSet,
+    'enterprise-offers',
+)
 router.register(
     r'enterprise/(?P<enterprise_id>.+)/users',
     views.EnterpriseLearnerViewSet,
